@@ -1,15 +1,13 @@
-from .angle import angle_between_vectors, compute_yaw_around_north_from_direction
+from .angle import angle_between_vectors, angular_distance, compute_yaw_around_north_from_direction
 from .image import crop_rectangle_from_image
 from .transform import (
+    compute_agent_pose,
     ecef_to_geodetic,
-    flip_y_axis,
     geodetic_to_ecef,
-    get_transformation_matrix,
     rotation33_as_yaw,
     transform_point,
     transform_points,
-    transform_points_transposed,
-    world_to_image_pixels_matrix,
+    vertical_flip,
     yaw_as_rotation33,
 )
 from .voxel import normalize_intensity, points_within_bounds, voxel_coords_to_intensity_grid
@@ -20,15 +18,14 @@ __all__ = [
     "crop_rectangle_from_image",
     "rotation33_as_yaw",
     "yaw_as_rotation33",
-    "world_to_image_pixels_matrix",
-    "flip_y_axis",
+    "vertical_flip",
     "transform_points",
-    "transform_points_transposed",
     "transform_point",
-    "get_transformation_matrix",
     "ecef_to_geodetic",
     "geodetic_to_ecef",
     "points_within_bounds",
     "voxel_coords_to_intensity_grid",
     "normalize_intensity",
+    "angular_distance",
+    "compute_agent_pose",
 ]
