@@ -1,4 +1,4 @@
-from typing import cast
+from typing import Union, cast
 
 import numpy as np
 
@@ -29,3 +29,18 @@ the y-axis direction vector (0, 1).
         float: angle to (0,1) vector in radians
     """
     return angle_between_vectors(direction_vector, np.array([0.0, 1.0]))
+
+
+def angular_distance(angle_a: Union[float, np.ndarray], angle_b: Union[float, np.ndarray]) -> Union[float, np.ndarray]:
+    """ A function that takes two arrays of angles in radian and compute the angular distance, wrap the angular
+    distance such that they are always in the [-pi, pi) range.
+
+    Args:
+        angle_a (np.ndarray, float): first array of angles in radians
+        angle_b (np.ndarray, float): second array of angles in radians
+
+    Returns:
+        angular distance in radians between two arrays of angles
+    """
+
+    return (angle_a - angle_b + np.pi) % (2 * np.pi) - np.pi
