@@ -1,6 +1,7 @@
 from .box_rasterizer import BoxRasterizer
 from .rasterizer import EGO_EXTENT_HEIGHT, EGO_EXTENT_LENGTH, EGO_EXTENT_WIDTH, Rasterizer
 from .rasterizer_builder import build_rasterizer
+from .render_context import RenderContext
 from .sat_box_rasterizer import SatBoxRasterizer
 from .satellite_image import get_sat_image_crop, get_sat_image_crop_scaled, get_sat_image_crop_scaled_from_ecef
 from .satellite_rasterizer import SatelliteRasterizer
@@ -13,6 +14,7 @@ __all__ = [
     "get_sat_image_crop_scaled",
     "get_sat_image_crop",
     "Rasterizer",
+    "RenderContext",
     "SatelliteRasterizer",
     "SemanticRasterizer",
     "StubRasterizer",
