@@ -1,5 +1,11 @@
 from .gif import write_gif
-from .utils import PREDICTED_POINTS_COLOR, TARGET_POINTS_COLOR, draw_reference_trajectory, draw_trajectory
+from .utils import (
+    PREDICTED_POINTS_COLOR,
+    REFERENCE_TRAJ_COLOR,
+    TARGET_POINTS_COLOR,
+    draw_reference_trajectory,
+    draw_trajectory,
+)
 from .video import write_video
 
 __all__ = [
@@ -9,4 +15,5 @@ __all__ = [
     "draw_trajectory",
     "TARGET_POINTS_COLOR",
     "PREDICTED_POINTS_COLOR",
+    "REFERENCE_TRAJ_COLOR",
 ]
