@@ -1,4 +1,4 @@
-from typing import Tuple
+from typing import Optional, Tuple
 
 import cv2
 import numpy as np
@@ -7,7 +7,7 @@ from l5kit.geometry import transform_point, transform_points
 
 PREDICTED_POINTS_COLOR = (0, 255, 255)
 TARGET_POINTS_COLOR = (255, 0, 255)
-REFERENCE_TRAJECTORY_POINT_COLOR = (255, 255, 0)
+REFERENCE_TRAJ_COLOR = (255, 255, 0)
 #  Arrows represent position + orientation.
 ARROW_LENGTH_IN_PIXELS = 2
 ARROW_THICKNESS_IN_PIXELS = 1
@@ -28,7 +28,8 @@ def draw_arrowed_line(on_image: np.ndarray, position: np.ndarray, yaw: float, rg
     """
     start_pixel = np.array(position[:2])
 
-    rot = cv2.getRotationMatrix2D((0, 0), np.degrees(-yaw), 1.0)  # minus here because of cv2 rotations convention
+    rot = np.eye(3)
+    rot[:-1] = cv2.getRotationMatrix2D((0, 0), np.degrees(-yaw), 1.0)  # minus here because of cv2 rotations convention
     end_pixel = start_pixel + transform_point(np.asarray([ARROW_LENGTH_IN_PIXELS, 0]), rot)
 
     cv2.arrowedLine(
@@ -42,23 +43,34 @@ def draw_arrowed_line(on_image: np.ndarray, position: np.ndarray, yaw: float, rg
 
 
 def draw_trajectory(
-    on_image: np.ndarray, positions: np.ndarray, yaws: np.ndarray, rgb_color: Tuple[int, int, int],
+    on_image: np.ndarray,
+    positions: np.ndarray,
+    rgb_color: Tuple[int, int, int],
+    radius: int = 1,
+    yaws: Optional[np.ndarray] = None,
 ) -> None:
     """
     Draw a trajectory on oriented arrow onto an RGB image
     Args:
         on_image (np.ndarray): the RGB image to draw onto
-        positions (np.ndarray): pixel coordinates in the image space (not displacements)
-        yaws (np.ndarray): yaws in radians
+        positions (np.ndarray): pixel coordinates in the image space (not displacements) (Nx2)
         rgb_color (Tuple[int, int, int]): the trajectory RGB color
+        radius (int): radius of the circle
+        yaws (Optional[np.ndarray]): yaws in radians (N) or None to disable yaw visualisation
 
     Returns: None
 
     """
-    for pos, yaw in zip(positions, yaws):
-        pred_waypoint = pos[:2]
-        pred_yaw = float(yaw[0])
-        draw_arrowed_line(on_image, pred_waypoint, pred_yaw, rgb_color)
+    if yaws is not None:
+        assert len(yaws) == len(positions)
+        for pos, yaw in zip(positions, yaws):
+            pred_waypoint = pos[:2]
+            pred_yaw = float(yaw[0])
+            draw_arrowed_line(on_image, pred_waypoint, pred_yaw, rgb_color)
+    else:
+        for pos in positions:
+            pred_waypoint = pos[:2]
+            cv2.circle(on_image, tuple(pred_waypoint.astype(np.int)), radius, rgb_color, -1)
 
 
 def draw_reference_trajectory(on_image: np.ndarray, world_to_pixel: np.ndarray, positions: np.ndarray) -> None:
@@ -77,4 +89,4 @@ def draw_reference_trajectory(on_image: np.ndarray, world_to_pixel: np.ndarray,
     mask = np.all(positions_in_pixel_space > (0.0, 0.0), 1) * np.all(positions_in_pixel_space < on_image.shape[:2], 1)
     positions_in_pixel_space = positions_in_pixel_space[mask]
     for pos in positions_in_pixel_space:
-        cv2.circle(on_image, tuple(np.floor(pos).astype(np.int32)), 1, REFERENCE_TRAJECTORY_POINT_COLOR, -1)
+        cv2.circle(on_image, tuple(np.floor(pos).astype(np.int32)), 1, REFERENCE_TRAJ_COLOR, -1)
